#
# spec file for package solanum
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           solanum
Version:        0~ch634
Release:        bp156.1.6
Summary:        Scalable IRCv3.2 compliant chat daemon
License:        GPL-2.0-or-later
Group:          Productivity/Networking/IRC
URL:            https://github.com/solanum-ircd/solanum

Source:         %name-%version.tar.xz
Source1:        %name-sysusers.conf
Source9:        example.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  sqlite3-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libcrypto) >= 0.9.7
BuildRequires:  pkgconfig(libssl) >= 0.9.7
BuildRequires:  pkgconfig(zlib)
Requires(pre):  shadow
Obsoletes:      charybdis

%description
Solanum is an IRCv3.2 compatible chat server. It is a continuation of the
Charybdis server and has good documentation and ease of configuration.
It is used by Libera, the largest (as of 2023) IRC network in the world.

%prep
%autosetup -p1 -n %name-%version

%build
mkdir libltdl
autoreconf -fiv
%configure --sysconfdir="%_sysconfdir/%name" \
	--with-logdir="%_localstatedir/log/%name" \
	--with-rundir="/run" --localstatedir="%_localstatedir/lib"
%make_build

%install
b="%buildroot"
%make_install
mv "$b/%_bindir"/* "$b/%_libexecdir/%name/"
find "$b/%_libdir" -type f -name "*.la" -delete

# Move config file samples/documentation out of the way
mv "$b/%_sysconfdir/%name"/*.conf "$b/%_datadir/%name/"
# Place some config file that will make it run out of the box on localhost
cp "%{S:9}" "$b/%_sysconfdir/%name/ircd.conf"

install -D %SOURCE1 %{buildroot}%{_sysusersdir}/%name.conf

mkdir -p "$b/%_localstatedir/lib/solanum" \
	"$b/%_localstatedir/log/solanum" "$b/%_sbindir" \
	"$b/%_unitdir" "$b/%_sysusersdir" "$b/%_tmpfilesdir"
cat >"$b/%_unitdir/solanum.service" <<-EOF
	[Unit]
	Description=Solanum Inter Relay Chat server
	[Service]
	ExecStart=%_libexecdir/%name/%name -foreground
	User=solanum
	Group=solanum
	[Install]
	WantedBy=multi-user.target
EOF
cat >"$b/%_tmpfilesdir/solanum.conf" <<-EOF
	d /run/%name 0755 solanum solanum -
EOF
# There are no headers installed, so the .pc and devel .so is useless
rm -Rf "$b/%_libdir/pkgconfig" "$b/%_libdir/libratbox.so"

%pre
%sysusers_create_package %name %SOURCE1
%service_add_pre %name.service

%post
%service_add_post %name.service
%tmpfiles_create %name.conf

%preun
%service_del_preun %name.service

%postun
%service_del_postun %name.service

%files
%attr(0750,root,solanum) %dir %_sysconfdir/%name
%attr(0640,root,solanum) %config %_sysconfdir/%name/*
%_libexecdir/%name/
%_libdir/%name/
%_libdir/libircd.so
%_libdir/librb.so
%_datadir/%name/
%_sysusersdir/*
%_tmpfilesdir/*
%_unitdir/*.service
%attr(0750,solanum,solanum) %_localstatedir/log/%name/
%attr(0750,solanum,solanum) %_localstatedir/lib/%name/
%license LICENSE
%doc NEWS.md

%changelog
* Sun Jul 23 2023 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 0~ch640 (0ca18d072)
  * Add umode +I to allow users to hide their idle time
  * Make +R play nicely with +z
  * Note that messages caught in +g/+G are discarded
  * m_shedding: plugin for user shedding based on oftc-hybrid
  * Add ACCOUNTEXTBAN ISUPPORT token
* Tue Jun 20 2023 Franck Bui <fbui@suse.com>
- Convert %%sysusers_create_inline into %%sysusers_create_package
  %%sysusers_create_inline is deprecated and will go away soon.
* Fri May 20 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve broken scriptlet, which warned
  "[-:1] Missing action and name columns" during installation.
* Sat Apr 30 2022 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 0~ch560 (48a06ae3)
  * Support more human friendly k/d/x-line duration format
  * Make opers talking through +g controllable by user mode +M
  * Apply cmode C to replies
* Tue May  4 2021 Jan Engelhardt <jengelh@inai.de>
- Move to Solanum codebase/Update to snapshot (3ff5a12e)
- Drop 0001-Set-EXTERNAL_BUILD_TIMESTAMP-from-SOURCE_DATE_EPOCH.patch
  (merged)
* Thu Oct  1 2020 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Set-EXTERNAL_BUILD_TIMESTAMP-from-SOURCE_DATE_EPOCH.patch
  for reproducible builds.
* Sun Sep 29 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.1.2
  * Do not corrupt usermodes on module unload/reload.
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- Update to upstream release 4.1.1
  * Implemented IRCv3.2 enhanced capability negotiation
    ("CAP LS 302").
  * Implemented support for receiving and sending IRCv3 message
    tags.
  * Implemented IRCv3.2 capabilities: account-tag, echo-message,
    invite-notify, sasl, server-time.
  * Feature from ircd-seven: Implement a channel mode that
    disallows kicking IRC operators (+M).
  * DNS, ident, and blacklist lookups have been moved to a
    dedicated daemon known as authd. Some cosmetic changes to
    blacklist statistics and rejection notices have resulted.
  * Support for WebSocket has been added.
  * Added the ability to strip color codes from topics
    unconditionally.
  * SCTP is now supported for server and user connections.
- Remove charybdis-ratbox.diff, charybdis-werror.diff (no longer
  needed), charybdis-repro.diff (solved differently upstream).
* Tue Jan 10 2017 jengelh@inai.de
- Add charybdis-repro.diff, throw out buildtime-dependent
  constructs
* Sun Nov 20 2016 jengelh@inai.de
- Update description
- Abort installation if user/group cannot be created
* Wed Sep 21 2016 jengelh@inai.de
- Update to new upstream release 3.5.3
  * Bug fix for CVE-2016-7143. This bug allows users to spoof CertFP
  authentication using the SASL EXTERNAL mechanism.
* Sun Jun 19 2016 jengelh@inai.de
- Update to new upstream release 3.5.2
  * Allow IRCv3.1 STARTTLS to work with other SSL backends besides
  OpenSSL.
  * Fix an edge case regression involving channel ban cache that was
  introduced in 3.5.0.
  * Ensure ssld does not crash when DH parameters are not provided.
  * mbedtls TLS backend improvements from charybdis 4 development
  branch:
  * add support for CertFP
  * provide personalization data for the PRNG
  * openssl TLS backend improvements from charybdis 4:
  * do not manually initialise openssl when running with OpenSSL
  1.1.0 or later
  * support ECDHE on more than one curve on OpenSSL 1.0.2 and above
  * fix DH parameters memory leak
  * free the old TLS context before constructing a new one
* Sat May  7 2016 jengelh@inai.de
- Update to new upstream release 3.5.1
  * Fix propagation of ip_cloaking hostname changes (only when
  setting or unsetting the umode after connection).
  * Fix a remote-triggerable crash triggered by the CAPAB parsing
  code.
  * As per the TS6 spec, require QS and ENCAP capabilities.
  * Require EX and IE capabilities (+e and +I cmodes).
  * Check that UIDs start with the server's SID.
  * Allow mode queries on mlocked modes. In particular, allow
  `/mode #channel f` to query the forward channel even if
  +f is mlocked.
  * Add starttls as per ircv3.
  * Reject nicks with '~' in them, rather than truncating at the '~'.
  * Do not allow SASL authentication when the configured SASL agent
  is unavailable.
  * Implement IRCv3.2 capabilities: cap-notify, chghost,
  userhost-in-names
  * Implement the $&, $| and $m extban types:
  * $& combines 1 or more child extbans as an AND expression
  * $| combines 1 or more child extbans as an OR expression
  * $m provides normal hostmask matching as an extban for the above
  * Display an operator's privilege set in WHOIS.
  * The $o extban now matches against privilege set names as well as
  individual privileges. Privilege set names are preferred over
  individual privileges.
* Mon Oct  6 2014 jengelh@inai.de
- Update to new upstream release 3.4.2
  * A new extban, $z, has been added for ssl users (extb_ssl)
  * Remove TS5 support
  * Replace oper flags by privilege sets (privsets)
  * Add cmode +C (no CTCP) from ircd-seven.
  * Add bandb from ircd-ratbox, which stores permanent
  [DKX]lines/resvs in an sqlite database instead of a flatfile
- Add charybdis-ratbox.diff, charybdis-werror.diff
* Sun Oct 28 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Feed through format_spec_file service
- Add systemd service file
* Sun Sep 30 2007 mrueckert@suse.de
- update to version 2.2.0
- also build the unsupported modules
* Sat Apr 14 2007 mrueckert@suse.de
- update to version 2.1.3
* Sat Apr 14 2007 mrueckert@suse.de
- fix build requires for factory
- add missing %%dir entry
* Mon Nov 27 2006 mrueckert@suse.de
- use assembler stuff only on ix86
* Mon Nov 27 2006 mrueckert@suse.de
- initial package.
